@@ -1,8 +1,8 @@
 context("Arithmetic")
 
 test_that("we can compare vectors with equal units", {
-  x <- 1:4 * make_unit("m")
-  y <- 1:4 * make_unit("m")
+  x <- 1:4 * as_units("m")
+  y <- 1:4 * as_units("m")
   z <- 2 * y
   
   expect_true(all(x == y))
@@ -21,7 +21,7 @@ test_that("we can compare vectors with equal units", {
 
 test_that("we can scale units with scalars", {
   x <- 1:4
-  ux <- x * make_unit("m")
+  ux <- x * as_units("m")
   
   expect_equal(as.numeric(10 * ux), 10 * x)
   expect_equal(as.numeric(ux / 10), x / 10)
@@ -29,8 +29,8 @@ test_that("we can scale units with scalars", {
 
 test_that("we can multiply and divide units", {
   x <- 1:4 ; y <- 5:8
-  m <- x * make_unit("m")
-  s <- y * make_unit("s")
+  m <- x * as_units("m")
+  s <- y * as_units("s")
   
   expect_equal(as.numeric(m * s), x * y)
   expect_equal(as.numeric(m / s), x / y)
@@ -43,7 +43,7 @@ test_that("we can multiply and divide units", {
 
 test_that("we can take powers of units", {
   x <- 1:4
-  ux <- x * make_unit("m")
+  ux <- x * as_units("m")
   
   expect_equal(as.numeric(ux ** 2), x ** 2)
   expect_equal(as.numeric(ux ^ 2), x ^ 2)
@@ -62,17 +62,22 @@ test_that("we can take powers of units", {
   
   expect_equal(as.numeric(ux ** 0), x ** 0)
   expect_equal(as.numeric(ux ^ 0), x ^ 0)
-  expect_equal(units(ux ** 0), unitless)
-  expect_equal(units(ux ^ 0), unitless)
+  expect_identical(units(ux ** 0), set_units(1))
+  expect_identical(units(ux ^ 0), set_units(1))
+})
+
+test_that("we support unary +/-", {
+  expect_equal(-set_units(10, m), set_units(-10, m))
+  expect_equal(+set_units(10, m), set_units(10, m))
 })
 
 test_that("we can convert units and simplify after multiplication", {
   x <- 1:4
   y <- 1:4
   z <- 1:4
-  m <- make_unit("m")
-  s <- make_unit("s")
-  km <- make_unit("km")
+  m <- as_units("m")
+  s <- as_units("s")
+  km <- as_units("km")
   ux <- x * m
   uy <- y * s
   uz <- z * km
@@ -84,8 +89,8 @@ test_that("we can convert units and simplify after multiplication", {
   expect_equal(as.character(units(ux*uy)), "m*s")
   expect_equal(as.numeric(ux*uz), x*z)
   expect_equal(as.character(units(ux*uz)), "km*m")
-  expect_equal(as.numeric(as_units(ux*uz, km * km)), (x/1000)*z)
-  expect_equal(as.character(units(as_units(ux*uz, km * km))), "km^2")
+  expect_equal(as.numeric(set_units(ux*uz, km * km)), (x/1000)*z)
+  expect_equal(as.character(units(set_units(ux*uz, km * km))), "km^2")
   
   expect_equal(as.numeric(ux/ux), x/x)
   expect_equal(as.character(units(ux/ux)), "1")
@@ -97,6 +102,21 @@ test_that("we can convert units and simplify after multiplication", {
   expect_equal(as.character(units(ux/uy/uz)), "1/s")
 })
 
+test_that("unit one is handled correctly", {
+  one <- set_units(1)
+  onem <- set_units(1, m)
+
+  expect_equal(one * one, one)
+  expect_equal(onem * one, onem)
+  expect_equal(one * one * one, one) 
+  expect_equal(onem * one * one, onem)
+  expect_equal(one / one, one)
+  expect_equal(onem / one, onem)
+  expect_equal(one ^ 3, one)
+#  expect_equal(one ^ pi, one)
+#  expect_equal(one ^ -pi, one)
+})
+
 test_that("we can compute powers +/- 1/n for integer n", {
   expect_equal(as.numeric(set_units(1:10, m^2) ^ 0.5), (1:10) ^ .5)
   expect_error(as.numeric(set_units(1:10, m^3) ^ 0.5), "units not divisible")
@@ -107,3 +127,12 @@ test_that("we can compute powers +/- 1/n for integer n", {
   expect_error(set_units(1:10, m^2) ^ (1/pi), "not a integer divisor")
   expect_error(set_units(1:10, m^3) ^ -1.5, "currently you can only take integer powers of units below -1")
 })
+
+test_that("%*%, %/% and %% work", {
+  a = set_units(1:5, m)
+  expect_equal(a %/% set_units(2, m), set_units(c(0,1,1,2,2)))
+  expect_equal(a %% set_units(2, m), set_units(c(1,0,1,0,1), m))
+  mat = set_units(matrix(1:5, 1), m)
+  expect_equal(mat %*% t(mat), set_units(matrix(55), m^2))
+  expect_equal(t(mat) %*% mat, set_units(t(unclass(mat)) %*% unclass(mat), m^2))
+})
